import type { Base58EncodedBytes, Blockhash, Commitment, IRpcApiSubscriptions, RpcResponse, Slot, U64UnsafeBeyond2Pow53Minus1, UnixTimestamp } from '@solana/rpc-types';
import { TransactionVersion } from '@solana/transactions';
import { Reward, TransactionForAccounts, TransactionForFullBase58, TransactionForFullBase64, TransactionForFullJson, TransactionForFullJsonParsed } from '../rpc-methods/common-transactions.js';
type BlockNotificationsNotificationBase = Readonly<{
    /**
     * Errors can arise in generating a block notification.
     * If an error is encountered, this field will contain the error, and the `block` field will return null.
     * @see https://github.com/solana-labs/solana/blob/6ea51280ddc235ed93e16906c3427efd20cd7ce4/rpc/src/rpc_subscriptions.rs#L1059-L1074
     * @see https://github.com/solana-labs/solana/blob/6ea51280ddc235ed93e16906c3427efd20cd7ce4/rpc-client-api/src/response.rs#L507-L514
     */
    err: string | null;
    slot: Slot;
}>;
type BlockNotificationsNotificationBlock = Readonly<{
    /** The number of blocks beneath this block */
    blockHeight: U64UnsafeBeyond2Pow53Minus1;
    /** The number of blocks beneath this block */
    blockTime: UnixTimestamp;
    /** the blockhash of this block */
    blockhash: Blockhash;
    /** The slot index of this block's parent */
    parentSlot: Slot;
    /** The blockhash of this block's parent */
    previousBlockhash: Blockhash;
}>;
type BlockNotificationsNotificationBlockWithRewards = Readonly<{
    /** Block-level rewards */
    rewards: readonly Reward[];
}>;
type BlockNotificationsNotificationBlockWithSignatures = Readonly<{
    /** List of signatures applied to transactions in this block */
    signatures: readonly Base58EncodedBytes[];
}>;
type BlockNotificationsNotificationBlockWithTransactions<TTransaction> = Readonly<{
    transactions: readonly TTransaction[];
}>;
type BlockNotificationsFilter = 'all' | {
    mentionsAccountOrProgram: string;
};
type BlockNotificationsCommonConfig = Readonly<{
    /** @defaultValue finalized */
    commitment?: Omit<Commitment, 'processed'>;
}>;
type BlockNotificationsEncoding = 'base58' | 'base64' | 'json' | 'jsonParsed';
type BlockNotificationsMaxSupportedTransactionVersion = Exclude<TransactionVersion, 'legacy'>;
export interface BlockNotificationsApi extends IRpcApiSubscriptions {
    /**
     * Subscribe to receive notification anytime a new block is Confirmed or Finalized.
     *
     * Note: The `block` field is a block object as seen in the `getBlock` RPC HTTP method.
     * @see https://docs.solana.com/api/http#getblock
     */
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding?: BlockNotificationsEncoding;
        maxSupportedTransactionVersion?: BlockNotificationsMaxSupportedTransactionVersion;
        showRewards: false;
        transactionDetails: 'none';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: BlockNotificationsNotificationBlock | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding?: BlockNotificationsEncoding;
        maxSupportedTransactionVersion?: BlockNotificationsMaxSupportedTransactionVersion;
        showRewards?: true;
        transactionDetails: 'none';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithRewards) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding?: BlockNotificationsEncoding;
        maxSupportedTransactionVersion?: BlockNotificationsMaxSupportedTransactionVersion;
        showRewards: false;
        transactionDetails: 'signatures';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithSignatures) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding?: BlockNotificationsEncoding;
        maxSupportedTransactionVersion?: BlockNotificationsMaxSupportedTransactionVersion;
        showRewards?: true;
        transactionDetails: 'signatures';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithSignatures & BlockNotificationsNotificationBlockWithRewards) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding?: BlockNotificationsEncoding;
        maxSupportedTransactionVersion: BlockNotificationsMaxSupportedTransactionVersion;
        showRewards: false;
        transactionDetails: 'accounts';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForAccounts<BlockNotificationsMaxSupportedTransactionVersion>>) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding?: BlockNotificationsEncoding;
        showRewards: false;
        transactionDetails: 'accounts';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForAccounts<void>>) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding?: BlockNotificationsEncoding;
        maxSupportedTransactionVersion: BlockNotificationsMaxSupportedTransactionVersion;
        showRewards?: true;
        transactionDetails: 'accounts';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForAccounts<BlockNotificationsMaxSupportedTransactionVersion>> & BlockNotificationsNotificationBlockWithRewards) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding?: BlockNotificationsEncoding;
        showRewards?: true;
        transactionDetails: 'accounts';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForAccounts<void>> & BlockNotificationsNotificationBlockWithRewards) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding: 'base58';
        maxSupportedTransactionVersion: BlockNotificationsMaxSupportedTransactionVersion;
        showRewards: false;
        transactionDetails?: 'full';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForFullBase58<BlockNotificationsMaxSupportedTransactionVersion>>) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding: 'base58';
        showRewards: false;
        transactionDetails?: 'full';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForFullBase58<void>>) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding: 'base58';
        maxSupportedTransactionVersion: BlockNotificationsMaxSupportedTransactionVersion;
        showRewards?: true;
        transactionDetails?: 'full';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForFullBase58<BlockNotificationsMaxSupportedTransactionVersion>> & BlockNotificationsNotificationBlockWithRewards) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding: 'base58';
        showRewards?: true;
        transactionDetails?: 'full';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForFullBase58<void>> & BlockNotificationsNotificationBlockWithRewards) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding: 'base64';
        maxSupportedTransactionVersion: BlockNotificationsMaxSupportedTransactionVersion;
        showRewards: false;
        transactionDetails?: 'full';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForFullBase64<BlockNotificationsMaxSupportedTransactionVersion>>) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding: 'base64';
        showRewards: false;
        transactionDetails?: 'full';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForFullBase64<void>>) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding: 'base64';
        maxSupportedTransactionVersion: BlockNotificationsMaxSupportedTransactionVersion;
        showRewards?: true;
        transactionDetails?: 'full';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForFullBase64<BlockNotificationsMaxSupportedTransactionVersion>> & BlockNotificationsNotificationBlockWithRewards) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding: 'base64';
        showRewards?: true;
        transactionDetails?: 'full';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForFullBase64<void>> & BlockNotificationsNotificationBlockWithRewards) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding: 'jsonParsed';
        maxSupportedTransactionVersion: BlockNotificationsMaxSupportedTransactionVersion;
        showRewards: false;
        transactionDetails?: 'full';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForFullJsonParsed<BlockNotificationsMaxSupportedTransactionVersion>>) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding: 'jsonParsed';
        showRewards: false;
        transactionDetails?: 'full';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForFullJsonParsed<void>>) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding: 'jsonParsed';
        maxSupportedTransactionVersion: BlockNotificationsMaxSupportedTransactionVersion;
        showRewards?: true;
        transactionDetails?: 'full';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForFullJsonParsed<BlockNotificationsMaxSupportedTransactionVersion>> & BlockNotificationsNotificationBlockWithRewards) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding: 'jsonParsed';
        showRewards?: true;
        transactionDetails?: 'full';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForFullJsonParsed<void>> & BlockNotificationsNotificationBlockWithRewards) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding?: 'json';
        maxSupportedTransactionVersion: BlockNotificationsMaxSupportedTransactionVersion;
        showRewards: false;
        transactionDetails?: 'full';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForFullJson<BlockNotificationsMaxSupportedTransactionVersion>>) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding?: 'json';
        showRewards: false;
        transactionDetails?: 'full';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForFullJson<void>>) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config: BlockNotificationsCommonConfig & Readonly<{
        encoding?: 'json';
        maxSupportedTransactionVersion: BlockNotificationsMaxSupportedTransactionVersion;
        showRewards?: true;
        transactionDetails?: 'full';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForFullJson<BlockNotificationsMaxSupportedTransactionVersion>> & BlockNotificationsNotificationBlockWithRewards) | null;
    }>>;
    blockNotifications(filter: BlockNotificationsFilter, config?: BlockNotificationsCommonConfig & Readonly<{
        encoding?: 'json';
        showRewards?: true;
        transactionDetails?: 'full';
    }>): RpcResponse<BlockNotificationsNotificationBase & Readonly<{
        block: (BlockNotificationsNotificationBlock & BlockNotificationsNotificationBlockWithTransactions<TransactionForFullJson<void>> & BlockNotificationsNotificationBlockWithRewards) | null;
    }>>;
}
export {};
//# sourceMappingURL=block-notifications.d.ts.map